@@ -1,6 +1,6 @@
-;;; no-littering.el --- help keeping ~/.emacs.d clean
+;;; no-littering.el --- help keeping ~/.emacs.d clean  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2016-2019  Jonas Bernoulli
+;; Copyright (C) 2016-2020  Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <jonas@bernoul.li>
 ;; Homepage: https://github.com/emacscollective/no-littering
@@ -198,6 +198,8 @@ This variable has to be set before `no-littering' is loaded.")
            (symbol-function #'no-littering-expand-etc-file-name))
           ((symbol-function 'var)
            (symbol-function #'no-littering-expand-var-file-name)))
+  (make-directory no-littering-etc-directory t)
+  (make-directory no-littering-var-directory t)
   (with-no-warnings ; many of these variables haven't been defined yet
 
 ;;; Built-in packages
@@ -207,16 +209,20 @@ This variable has to be set before `no-littering' is loaded.")
     (setq auto-save-list-file-prefix       (var "auto-save/sessions/"))
     (setq backup-directory-alist           (list (cons "." (var "backup/"))))
     (setq bookmark-default-file            (var "bookmark-default.el"))
+    (setq calc-settings-file               (etc "calc-settings.el"))
     (eval-after-load 'desktop
       `(make-directory ,(var "desktop/") t))
     (setq desktop-dirname                  (var "desktop/"))
     (setq desktop-path                     (list desktop-dirname))
     (setq diary-file                       (var "diary"))
+    (setq ede-project-placeholder-cache-file (var "ede-projects.el"))
     (setq epkg-repository                  (var "epkgs/"))
     (setq eshell-directory-name            (var "eshell/"))
+    (setq eudc-options-file                (etc "eudc-options.el"))
     (eval-after-load 'eww
       `(make-directory ,(var "eww/") t))
     (setq eww-bookmarks-directory          (var "eww/"))
+    (setq filesets-menu-cache-file         (var "filesets-menu-cache.el"))
     (setq gamegrid-user-score-file-directory (var "gamegrid-user-score/"))
     (setq ido-save-directory-list-file     (var "ido-save-directory-list.el"))
     (setq image-dired-db-file              (var "image-dired/db.el"))
@@ -229,6 +235,7 @@ This variable has to be set before `no-littering' is loaded.")
       `(make-directory ,(var "newsticker/") t))
     (setq newsticker-cache-filename        (var "newsticker/cache.el"))
     (setq newsticker-dir                   (var "newsticker/data/"))
+    (setq nix-buffer-directory-name        (var "nix-buffer/"))
     (setq nsm-settings-file                (var "nsm-settings.el"))
     (eval-after-load 'org
       `(make-directory ,(var "org/") t))
@@ -237,11 +244,15 @@ This variable has to be set before `no-littering' is loaded.")
     (setq org-id-locations-file            (var "org/id-locations.el"))
     (setq org-publish-timestamp-directory  (var "org/timestamps/"))
     (setq org-registry-file                (var "org/registry.el"))
+    (setq project-list-file                (var "project-list"))
+    (setq quickurl-url-file                (var "quickurl-url.el"))
+    (setq rcirc-log-directory              (var "rcirc-log/"))
     (setq recentf-save-file                (var "recentf-save.el"))
     (setq remember-data-file               (var "remember/data"))
     (setq remember-data-directory          (var "remember/data.d/"))
     (setq save-place-file                  (var "save-place.el"))
     (setq savehist-file                    (var "savehist.el"))
+    (setq srecode-map-save-file            (var "srecode-map.el"))
     (setq semanticdb-default-save-directory (var "semantic/"))
     (setq shared-game-score-directory      (var "shared-game-score/"))
     (setq tramp-auto-save-directory        (var "tramp/auto-save/"))
@@ -256,6 +267,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq anaconda-mode-installation-directory (var "anaconda-mode/"))
     (setq annotate-file                    (var "annotations.el"))
     (setq async-byte-compile-log-file      (var "async-bytecomp.log"))
+    (setq auto-package-update-last-update-day-path (var "auto-package-update-last-update-day"))
     (eval-after-load 'bbdb
       `(make-directory ,(var "bbdb/") t))
     (setq bbdb-file                        (var "bbdb/bbdb.el"))
@@ -283,6 +295,7 @@ This variable has to be set before `no-littering' is loaded.")
       `(make-directory ,(var "elfeed/") t))
     (setq elfeed-db-directory              (var "elfeed/db/"))
     (setq elfeed-enclosure-default-dir     (var "elfeed/enclosures/"))
+    (setq elpher-bookmarks-file            (var "elpher-bookmarks.el"))
     (eval-after-load 'x-win
       (let ((session-dir (var "emacs-session/")))
         `(progn
@@ -296,6 +309,7 @@ directories."
     (eval-after-load 'emojify
       `(make-directory ,(var "emojify/") t))
     (setq emojify-emojis-dir               (var "emojify/"))
+    (setq equake-persistent-display-file   (var "equake-persistent-display"))
     (setq forge-database-file              (var "forge/database.sqlite"))
     (setq forge-post-directory             (var "forge/posts/"))
     (setq geben-temporary-file-directory   (var "geben/"))
@@ -308,6 +322,7 @@ directories."
     (setq helm-adaptive-history-file       (var "helm/adaptive-history.el"))
     (setq helm-backup-path                 (var "helm/backup/"))
     (setq helm-github-stars-cache-file     (var "helm/github-stars-cache.el"))
+    (setq helm-net-curl-log-file           (var "helm/helm-curl.log"))
     (setq historian-save-file              (var "historian-save.el"))
     (setq indium-workspace-file            (var "indium/workspaces.el"))
     (setq irfc-directory                   (var "irfc/"))
@@ -320,15 +335,18 @@ directories."
       `(make-directory ,(var "jabber/history/") t))
     (setq keyfreq-file                     (var "keyfreq.el"))
     (setq keyfreq-file-lock                (var "keyfreq.lock"))
-    (eval-after-load 'lookup
-      `(make-directory ,(etc "lookup/") t))
     (setq libbcel-oauth-store-filename     (var "libbcel-oauth-store.el.gpg"))
     (setq litable-list-file                (var "litable-list.el"))
     (setq logview-cache-filename           (var "logview-cache"))
     (setq logview-views-file               (etc "logview-views"))
+    (eval-after-load 'lookup
+      `(make-directory ,(etc "lookup/") t))
     (setq lookup-init-directory            (etc "lookup/"))
     (setq lsp-python-ms-dir                (var "lsp-python-ms/"))
-    (setq lsp-session-file                 (var "lsp-session.el"))
+    (eval-after-load 'lsp-mode
+      `(make-directory ,(var "lsp/") t))
+    (setq lsp-server-install-dir           (var "lsp/server/"))
+    (setq lsp-session-file                 (var "lsp/session.el"))
     (setq lsp-java-workspace-dir           (var "lsp-java/workspace/"))
     (setq lsp-java-server-install-dir      (var "lsp-java/eclipse.jdt.ls/server/"))
     (setq magithub-dir                     (var "magithub/"))
@@ -378,6 +396,9 @@ directories."
     (setq transient-values-file            (etc "transient/values.el"))
     (setq treemacs-persist-file            (var "treemacs/persist.org"))
     (setq treemacs-last-error-persist-file (var "treemacs/persist-last-error.org"))
+    (setq type-break-file-name             (var "type-break.el"))
+    (setq undo-fu-session-directory        (var "undo-fu-session/"))
+    (setq undohist-directory               (var "undohist/"))
     (setq undo-tree-history-directory-alist (list (cons "." (var "undo-tree-hist/"))))
     (setq user-emacs-ensime-directory      (var "ensime/"))
     (setq vimish-fold-dir                  (var "vimish-fold/"))
